@@ -34,7 +34,7 @@ class Registry(BaseRegistry):
             for file in f_names:
                 file_ending = os.path.splitext(file)[1]
                 if file_ending in CHECKS_POSSIBLE_ENDING:
-                    with open(f"{root}/{file}", "r") as f:
+                    with open(os.path.join(root, file), "r") as f:
                         if dir != self.checks_dir:
                             self.logger.info(f"loading {file}")
                         check_yaml = yaml.safe_load(f)
@@ -45,7 +45,7 @@ class Registry(BaseRegistry):
                         check = self.parser.parse_raw_check(
                             check_json, resources_types=self._get_resource_types(check_json)
                         )
-                        if not any([c for c in self.checks if check.id == c.id]):
+                        if not any(c for c in self.checks if check.id == c.id):
                             if external_check:
                                 # Note the external check; used in the should_run_check logic
                                 RunnerFilter.notify_external_check(check.id)
