@@ -17,6 +17,7 @@ class OrSolver(BaseComplexSolver):
         return reduce(or_, args)
 
     def get_operation(self, vertex: Dict[str, Any]) -> bool:
-        if any(solver.get_operation(vertex) for solver in self.solvers):
-            return True
+        for solver in self.solvers:
+            if solver.get_operation(vertex):
+                return True
         return False
